==> nativescript-1.6.2.tgz: package/lib/common/mobile/ios/simulator/ios-simulator-application-manager.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var application_manager_base_1 = require("../../application-manager-base");
var Future = require("fibers/future");
var IOSSimulatorApplicationManager = (function (_super) {
    __extends(IOSSimulatorApplicationManager, _super);
    function IOSSimulatorApplicationManager(iosSim, identifier, $options) {
        _super.call(this);
        this.iosSim = iosSim;
        this.identifier = identifier;
        this.$options = $options;
        this.deviceLoggingStarted = false;
    }
    IOSSimulatorApplicationManager.prototype.getInstalledApplications = function () {
        return Future.fromResult(this.iosSim.getInstalledApplications(this.identifier));
    };
    IOSSimulatorApplicationManager.prototype.installApplication = function (packageFilePath) {
        return this.iosSim.installApplication(this.identifier, packageFilePath);
    };
    IOSSimulatorApplicationManager.prototype.uninstallApplication = function (appIdentifier) {
        return this.iosSim.uninstallApplication(this.identifier, appIdentifier);
    };
    IOSSimulatorApplicationManager.prototype.startApplication = function (appIdentifier) {
        var _this = this;
        return (function () {
            var launchResult = _this.iosSim.startApplication(_this.identifier, appIdentifier).wait();
            if (!_this.$options.justlaunch && !_this.deviceLoggingStarted) {
                _this.deviceLoggingStarted = true;
                _this.iosSim.printDeviceLog(_this.identifier, launchResult);
            }
        }).future()();
    };
    IOSSimulatorApplicationManager.prototype.stopApplication = function (cfBundleExecutable) {
        return this.iosSim.stopApplication(this.identifier, cfBundleExecutable);
    };
    IOSSimulatorApplicationManager.prototype.canStartApplication = function () {
        return true;
    };
    return IOSSimulatorApplicationManager;
})(application_manager_base_1.ApplicationManagerBase);
exports.IOSSimulatorApplicationManager = IOSSimulatorApplicationManager;

==> nativescript-2.0.0-2016-04-19-001.tgz: package/lib/common/mobile/ios/simulator/ios-simulator-application-manager.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var application_manager_base_1 = require("../../application-manager-base");
var Future = require("fibers/future");
var path = require("path");
var IOSSimulatorApplicationManager = (function (_super) {
    __extends(IOSSimulatorApplicationManager, _super);
    function IOSSimulatorApplicationManager(iosSim, identifier, $options, $fs, $bplistParser) {
        _super.call(this);
        this.iosSim = iosSim;
        this.identifier = identifier;
        this.$options = $options;
        this.$fs = $fs;
        this.$bplistParser = $bplistParser;
        this.deviceLoggingStarted = false;
    }
    IOSSimulatorApplicationManager.prototype.getInstalledApplications = function () {
        return Future.fromResult(this.iosSim.getInstalledApplications(this.identifier));
    };
    IOSSimulatorApplicationManager.prototype.installApplication = function (packageFilePath) {
        return this.iosSim.installApplication(this.identifier, packageFilePath);
    };
    IOSSimulatorApplicationManager.prototype.uninstallApplication = function (appIdentifier) {
        return this.iosSim.uninstallApplication(this.identifier, appIdentifier);
    };
    IOSSimulatorApplicationManager.prototype.startApplication = function (appIdentifier) {
        var _this = this;
        return (function () {
            var launchResult = _this.iosSim.startApplication(_this.identifier, appIdentifier).wait();
            if (!_this.$options.justlaunch && !_this.deviceLoggingStarted) {
                _this.deviceLoggingStarted = true;
                _this.iosSim.printDeviceLog(_this.identifier, launchResult);
            }
        }).future()();
    };
    IOSSimulatorApplicationManager.prototype.stopApplication = function (cfBundleExecutable) {
        return this.iosSim.stopApplication(this.identifier, cfBundleExecutable);
    };
    IOSSimulatorApplicationManager.prototype.canStartApplication = function () {
        return true;
    };
    IOSSimulatorApplicationManager.prototype.isLiveSyncSupportedOnDevice = function (appIdentifier) {
        var _this = this;
        return (function () {
            var applicationPath = _this.iosSim.getApplicationPath(_this.identifier, appIdentifier);
            var pathToInfoPlist = path.join(applicationPath, "Info.plist");
            if (_this.$fs.exists(pathToInfoPlist).wait()) {
                var plistContent = _this.$bplistParser.parseFile(pathToInfoPlist).wait()[0];
                return !!plistContent && !!plistContent.IceniumLiveSyncEnabled;
            }
            return false;
        }).future()();
    };
    return IOSSimulatorApplicationManager;
})(application_manager_base_1.ApplicationManagerBase);
exports.IOSSimulatorApplicationManager = IOSSimulatorApplicationManager;
